@@ -7,7 +7,7 @@ use Mojo::Util 'class_to_path';
 use List::Util 'first';
 
 our $AUTHORITY = 'cpan:BEROV';
-our $VERSION   = '0.930';
+our $VERSION   = '0.931';
 our $CODENAME  = 'U+2C0A GLAGOLITIC CAPITAL LETTER INITIAL IZHE (Ⰺ)';
 
 use Ado::Control;
@@ -29,7 +29,7 @@ has sessions => sub { Ado::Sessions::get_instance(shift->config) };
 has home => sub {
     my $app   = shift;
     my $class = ref $app;
-    return $app->SUPER::home if $ENV{MOJO_HOME};     # MOJO_HOME was forsed
+    return $app->SUPER::home if $ENV{MOJO_HOME};     # MOJO_HOME was forced
     my @home    = splitdir $INC{class_to_path $class};
     my $moniker = $app->moniker;
     while (pop @home) {
@@ -164,19 +164,20 @@ Ado - a rapid active commotion (framework for web-projects on Mojolicious)
 
 =head1 DESCRIPTION
 
-L<Ado> is a framework for web-projects based on L<Mojolicious>,
-written in the L<Perl programming language|http://www.perl.org/>.
-This is the base application class. Ado C<ISA> L<Mojolicious>.
-For a more detailed description on what Ado is and how to get started with Ado see B<L<Ado::Manual>>.
+L<Ado> is a framework for web-projects based on L<Mojolicious>, written in the
+L<Perl programming language|http://www.perl.org/>.  This is the base
+application class. Ado C<ISA> L<Mojolicious>.  For a more detailed description
+on what Ado is and how to get started with Ado see B<L<Ado::Manual>>.
 
 =head1 ATTRIBUTES
 
-Ado inherits all attributes from Mojolicious and implements the following ones.
+Ado inherits all attributes from Mojolicious and implements the following new
+ones.
 
 =head2 ado_home
 
-Returns an instance of L<Mojo::Home> pointing to the
-base directory where L<Ado> is installed.
+Returns an instance of L<Mojo::Home> pointing to the base directory where
+L<Ado> is installed.
 
     ~$ ado eval 'say app->ado_home'
     /home/berov/opt/public_dev/Ado
@@ -190,17 +191,19 @@ Returns the current C<CODENAME>.
     #/where/is/your_app/rootdir
     $app->home;
 
-Returns the root directory into which $app is installed.
-The guessing order is the following:
+Returns the root directory into which $app is installed.  The guessing order is
+the following:
 
 =over
 
 =item 1. If C<$ENV{MOJO_HOME}> is defined, it is honored.
 
-=item 2. The upper directory of the directory in which the starting executable C<$app-E<gt>moniker> is found, e.g. C<bin/..>.
-This may happen to be the same as L</ado_home>.
+=item 2. The upper directory of the directory in which the starting executable
+C<$app-E<gt>moniker> is found, e.g. C<bin/..>.  This may happen to be the same
+as L</ado_home>.
 
-=item 3. Fallback to L<Mojo/home>. This is the usual behavior of any L<Mojo> application.
+=item 3. Fallback to L<Mojo/home>. This is the usual behavior of any L<Mojo>
+application.
 
 =back
 
@@ -221,58 +224,53 @@ the following new ones.
 
 =head2 startup
 
-Sets various default paths like C<templates>, C<site_templates>,
-C<public>. Defines L<Mojolicious/secrets> as sha1_sum of C<$moniker.$mode. $home>.
-Sets L<Mojolicious/controller_class>
-and L<Mojolicious::Routes/namespaces> to L<${CLASS}::Control>.
-Sets L<Mojolicious::Plugins/namespaces> to C<['Mojolicious::Plugin', "${CLASS}::Plugin"]>.
-Sets L<Mojolicious::Commands/namespaces> to C<${CLASS}::Command>.
-C<$CLASS> is usually L<Ado>.
-Then calls the following methods in the order they are listed.
+Sets various default paths like C<templates>, C<site_templates>, C<public>.
+Defines L<Mojolicious/secrets> as sha1_sum of C<$moniker.$mode. $home>.  Sets
+L<Mojolicious/controller_class> and L<Mojolicious::Routes/namespaces> to
+L<${CLASS}::Control>.  Sets L<Mojolicious::Plugins/namespaces> to
+C<['Mojolicious::Plugin', "${CLASS}::Plugin"]>.  Sets
+L<Mojolicious::Commands/namespaces> to C<${CLASS}::Command>.  C<$CLASS> is
+usually L<Ado>.  Then calls the following methods in the order they are listed.
 Returns void.
 
 You can amend this behavior in the application configuration file.
 
 =head2 load_config
 
-Checks C<$ENV{MOJO_CONFIG}> and if not set sets it to C<$app-E<gt>home/etc/ado.conf>.
-Loads L<Mojolicious::Plugin::Config> to do the rest of the dirty work.
-Returns $app.
+Checks C<$ENV{MOJO_CONFIG}> and if not set sets it to
+C<$app-E<gt>home/etc/ado.conf>.  Loads L<Mojolicious::Plugin::Config> to do the
+rest of the dirty work.  Returns $app.
 
 =head2 load_plugins
 
-Does not accept any parameters.
-Loads plugins listed in C<$config-E<gt>{plugins}>.
-C<$config-E<gt>{plugins}> is an C<ARRAYREF> in which each element is
-a C<HASHREF> with keys C<name> and C<config> or string representing the plugin name.
-The name of the plugin is expected to be string that can be passed to
-L<Mojolicious/plugin>.
-The C<config> values is another C<HASHREF> containing the configuration for the plugin.
-Plugins can be L<Mojolicious> or L<Ado> specific plugins.
-Every L<Ado::Plugin>::Foo must inherit from L<Ado::Plugin> which C<ISA>
-L<Mojolicious::Plugin>.
-Of course Mojolicious plugins can be used - we count on this.
-There are plenty of examples on CPAN.
-Returns $app.
+Does not accept any parameters.  Loads plugins listed in
+C<$config-E<gt>{plugins}>.  C<$config-E<gt>{plugins}> is an C<ARRAYREF> in
+which each element is a C<HASHREF> with keys C<name> and C<config> or string
+representing the plugin name.  The name of the plugin is expected to be string
+that can be passed to L<Mojolicious/plugin>.  The C<config> values is another
+C<HASHREF> containing the configuration for the plugin.  Plugins can be
+L<Mojolicious> or L<Ado> specific plugins.  Every L<Ado::Plugin>::Foo must
+inherit from L<Ado::Plugin> which C<ISA> L<Mojolicious::Plugin>.  Of course
+Mojolicious plugins can be used - we count on this.  There are plenty of
+examples on CPAN.  Returns $app.
 
 =head2 load_routes
 
-Does not accept any parameters.
-Loads predefined routes from C<$config-E<gt>routes>.
-C<$config-E<gt>routes> is an C<ARRAYREF> in which each element is a C<HASHREF> with
-keys corresponding to a method name and value the parameters that
-will be passed to the method. Currently we use the C<route> value to pass it
-to L<Mojolicious::Routes/route>,C<params> value is the second parameter to
-instantiate the route. C<via> and C<to> values are passed 
-to the newly created route.
-See L<Mojolicious::Routes::Route> and L<Mojolicious::Guides::Routing> for more.
+Does not accept any parameters.  Loads predefined routes from
+C<$config-E<gt>routes>.  C<$config-E<gt>routes> is an C<ARRAYREF> in which each
+element is a C<HASHREF> with keys corresponding to a method name and value the
+parameters that will be passed to the method. Currently we use the C<route>
+value to pass it to L<Mojolicious::Routes/route>,C<params> value is the second
+parameter to instantiate the route. C<via> and C<to> values are passed to the
+newly created route.  See L<Mojolicious::Routes::Route> and
+L<Mojolicious::Guides::Routing> for more.
 
 Returns $app.
 
 =head2 define_mime_types
 
-Defines any MIME types listed in C<ado.conf> in C<types =E<gt> {...}>.
-Returns $app.
+Defines any MIME types listed in C<ado.conf> in C<types =E<gt> {...}>.  Returns
+$app.
 
 =head1 SPONSORS
 
@@ -291,14 +289,13 @@ L<http://www.thefreedictionary.com/ado>,
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2015 Красимир Беров (Krasimir Berov).
+Copyright 2013-2016 Красимир Беров (Krasimir Berov).
 
-This program is free software, you can redistribute it and/or
-modify it under the terms of the
-GNU Lesser General Public License v3 (LGPL-3.0).
-You may copy, distribute and modify the software provided that
-modifications are open source. However, software that includes
-the license may release under a different license.
+This program is free software, you can redistribute it and/or modify it under
+the terms of the GNU Lesser General Public License v3 (LGPL-3.0).  You may
+copy, distribute and modify the software provided that modifications are open
+source. However, software that includes the license may release under a
+different license.
 
 See http://opensource.org/licenses/lgpl-3.0.html for more information.
 
